biosimulators_utils.model_lang.neuroml package — BioSimulators utils 0.1.154 documentation

# biosimulators_utils.model_lang.neuroml package

## Submodules

## biosimulators_utils.model_lang.neuroml.validation module

Utilities for validating NeuroML models

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2021-05-10

Copyright

  2021, Center for Reproducible Biomedical Modeling

License

  MIT

biosimulators_utils.model_lang.neuroml.validation.validate_model(filename, name=None, config=None)

  Check that a model is valid

  Parameters

    - filename (`str`) – path to model

    - name (`str`, optional) – name of model for use in error messages

    - config (`Config`, optional) – whether to fail on missing includes

  Returns

    - nested `list` of `str`: nested list of errors (e.g., required ids missing or ids not unique)

    - nested `list` of `str`: nested list of errors (e.g., required ids missing or ids not unique)

    - `neuroml.nml.nml.NeuroMLDocument`: model

  Return type

    `tuple`

biosimulators_utils.model_lang.neuroml.validation.validate_model_l1(filename)

  Check that a file is a valid NeuroML L1 model

  Parameters

    filename (`str`) – path to model

  Returns

    - `bool`: whether the file is valid

    - `str`: error message

  Return type

    `tuple`

biosimulators_utils.model_lang.neuroml.validation.validate_model_l2(filename)

  Check that a file is a valid NeuroML L2 model

  Parameters

    filename (`str`) – path to model

  Returns

    - `bool`: whether the file is valid

    - `str`: error message

  Return type

    `tuple`